<div align="center">
<img src="assets/youtube_analyzer-logo.png" alt="youtube_analyzer-logo" width="200"/>

![Versão](https://img.shields.io/badge/version-1.3-orange)
![Licença](https://img.shields.io/badge/license-MIT-orange)
[![Sponsor](https://img.shields.io/badge/📖Documentation-green)](https://github.com/PauloCesar-dev404/youtube_analyzer/blob/main/Docs/document.md)
<br><br>
<i>Obtenha detalhes completos de vídeos do YouTube com esta biblioteca incrível!</i>
<br>
</div>

### Funcionalidades
- [x] Obter detalhes de um vídeo
- [x] Obter legendas
- [x] Tradução de legendas
- [x] Analisar playlists
- [x] Obter detalhes de URIs de vídeos
- [x] Downloads de áudios e vídeos


---

### Contribuições
Se tiver dúvidas ou sugestões, abra uma [issue aqui](https://github.com/PauloCesar-dev404/youtube_analyzer/issues).

---

### Apoie o Projeto!

**Chainlink**
```
0x0038a0AB79286E882951eEC15c80400868335778
```
**Ethereum**
```
0x87deaB84FA4a9F1982CCeb540591d95FCf850363
```
**Bitcoin**
```
bc1qu8xl22lp0wjvqzne2g4yl46ayl8v5zrav3hzdq
```

---

<i>youtube_analyzer! 🚀</i>


